﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2012 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Windows.Forms;
using HeuristicLab.Encodings.DecisionList;
using HeuristicLab.MainForm;
using HeuristicLab.MainForm.WindowsForms;

namespace HeuristicLab.Problems.LCS.Views {
  [View("XCS Model")]
  [Content(typeof(DecisionList), true)]
  public partial class DecisionListView : AsynchronousContentView {

    public new DecisionList Content {
      get { return (DecisionList)base.Content; }
      set { base.Content = value; }
    }

    public DecisionListView() {
      InitializeComponent();
    }


    protected override void OnContentChanged() {
      base.OnContentChanged();
      UpdateDataGridView();
    }

    private void UpdateDataGridView() {
      if (InvokeRequired) {
        Invoke((Action)UpdateDataGridView);
      } else {
        if (Content == null) {
          dataGridView.Rows.Clear();
        } else {

          dataGridView.RowCount = Content.Rules.Count;

          int row = 0;
          foreach (var rule in Content.Rules) {
            dataGridView[0, row].Value = rule.ToString();
            row++;
          }

          dataGridView.AutoResizeColumns(DataGridViewAutoSizeColumnsMode.ColumnHeader);
          dataGridView.AutoResizeRowHeadersWidth(DataGridViewRowHeadersWidthSizeMode.AutoSizeToAllHeaders);
        }
      }
    }
  }
}
